Crate nsys

Crate nsys 



Native Systems Rust namespace

Re-exports

pub use color_utils as color;color-utils
pub use curses_utils as curses;curses-utils
pub use fmod_utils as fmod;fmod-utils
pub use gl_utils as gl;gl-utils
pub use math_utils as math;math-utils
pub use signal_utils as signal;signal-utils

Modules

filers-utils
File utilities
geometrymath-utils
Geometry utilities
logrs-utils
Logging macros
macrosrs-utils
Utility macros
numericrs-utils
Numeric utilities

Macros

addressrs-utils
Print the stringified expression followed by its pointer formatting
bitsrs-utils
Print the stringified expression followed by its bitstring formatting
displayrs-utils
Print the stringified expression followed by its display formatting
for_sequencers-utils
Expands into a series of for loops with the given block of code which should treat each type uniformly.
hexrs-utils
Print the stringified expression followed by its hexadecimal formatting
prettyrs-utils
Print the stringified expression followed by its pretty debug formatting
showrs-utils
Print the stringified expression followed by its debug formatting