Available on crate feature
rs-utils only.Expand description
File utilities
Functions
- file_
new_ append - Opens a new file at specified path for writing in append mode, recursively creating parent directories
- file_
new_ append_ incremental - Calls
file_new_appendon the path returned by feeding the file path tofile_path_incremental. - file_
path_ incremental - Returns the file path appended with suffix
-NwhereNgives the first available non-pre-existing filename starting from0. - file_
path_ incremental_ with_ extension - Like file path incremental but preserves the file extension if one is present.
- is_file
- If this returns true then
std::fs::File::createwill not fail with “is a directory” error.