continuous_segment2_aabb2

Function continuous_segment2_aabb2 

pub fn continuous_segment2_aabb2<S>(
    segment: Segment<S>,
    aabb: Aabb2<S>,
) -> Option<((Normalized<S>, Point2<S>), (Normalized<S>, Point2<S>))>
where S: Real,
Available on crate feature math-utils only.
Compute continuous intersection of a 2D line segment with a 2D AABB (rectangle).

The points are returned in the order given by the ordering of the points in the segment.

Note that a segment that is tangent to the AABB returns no intersection.