continuous_segment2_sphere2

Function continuous_segment2_sphere2 

pub fn continuous_segment2_sphere2<S>(
    segment: Segment<S>,
    sphere: Sphere2<S>,
) -> Option<((Normalized<S>, Point2<S>), (Normalized<S>, Point2<S>))>
where S: Real,
Available on crate feature math-utils only.
Compute continuous intersection of a 2D line segment with a 2D sphere (circle).

The points are returned in the order given by the ordering of the points in the segment.

Note that a segment that is tangent to the surface of the circle returns no intersection.