continuous_segment3_aabb3

Function continuous_segment3_aabb3 

pub fn continuous_segment3_aabb3<S>(
    segment: Segment<S>,
    aabb: Aabb3<S>,
) -> Option<((Normalized<S>, Point3<S>), (Normalized<S>, Point3<S>))>
where S: Real + Float + RelativeEq<Epsilon = S>,
Available on crate feature math-utils only.
Compute continuous intersection of a 3D line segment with an AABB.

The points are returned in the order given by the ordering of the points in the segment.

Note that a segment that is tangent to the AABB returns no intersection.