continuous_segment3_sphere3

Function continuous_segment3_sphere3 

pub fn continuous_segment3_sphere3<S>(
    segment: Segment<S>,
    sphere: Sphere3<S>,
) -> Option<((Normalized<S>, Point3<S>), (Normalized<S>, Point3<S>))>
where S: OrderedField + Sqrt,
Available on crate feature math-utils only.
Compute continuous intersection of a 3D line segment with a sphere.

The points are returned in the order given by the ordering of the points in the segment.

Note that a segment that is tangent to the surface of the sphere returns no intersection.