pub struct Aabb2<S> { /* private fields */ }math-utils only.Expand description
2D axis-aligned bounding box.
Min/max can be co-linear:
let x = Aabb2::with_minmax (
[0.0, 0.0].into(),
[0.0, 1.0].into()
).unwrap();But not identical:
// panic!
let x = Aabb2::with_minmax (
[0.0, 0.0].into(),
[0.0, 0.0].into()
).unwrap();Implementations
Sourceimpl<S> Aabb2<S>where
S: OrderedRing,
impl<S> Aabb2<S>where
S: OrderedRing,
Sourcepub fn with_minmax(min: Point2<S>, max: Point2<S>) -> Option<Aabb2<S>>
pub fn with_minmax(min: Point2<S>, max: Point2<S>) -> Option<Aabb2<S>>
Returns None if points are not min/max or points are identical
Sourcepub fn from_points(a: Point2<S>, b: Point2<S>) -> Option<Aabb2<S>>
pub fn from_points(a: Point2<S>, b: Point2<S>) -> Option<Aabb2<S>>
Returns None if points are identical
Sourcepub fn with_minmax_unchecked(min: Point2<S>, max: Point2<S>) -> Aabb2<S>
pub fn with_minmax_unchecked(min: Point2<S>, max: Point2<S>) -> Aabb2<S>
Construct a new AABB with given min and max points.
Debug panic if points are not min/max:
let b = Aabb2::with_minmax_unchecked (
[1.0, 1.0].into(),
[0.0, 0.0].into()); // panic!Debug panic if points are identical:
let b = Aabb2::with_minmax_unchecked (
[0.0, 0.0].into(),
[0.0, 0.0].into()); // panic!Sourcepub fn from_points_unchecked(a: Point2<S>, b: Point2<S>) -> Aabb2<S>
pub fn from_points_unchecked(a: Point2<S>, b: Point2<S>) -> Aabb2<S>
Construct a new AABB using the two given points to determine min/max.
Debug panic if points are identical:
let b = Aabb2::from_points_unchecked (
[0.0, 0.0].into(),
[0.0, 0.0].into()); // panic!Sourcepub fn containing(points: &[Point2<S>]) -> Option<Aabb2<S>>
pub fn containing(points: &[Point2<S>]) -> Option<Aabb2<S>>
Construct the minimum AABB containing the given set of points.
Returns None if fewer than 2 points are given or all points are identical:
assert!(Aabb2::<f32>::containing (&[]).is_none());assert!(Aabb2::containing (&[[0.0, 0.0].into()]).is_none());Sourcepub fn union(a: Aabb2<S>, b: Aabb2<S>) -> Aabb2<S>
pub fn union(a: Aabb2<S>, b: Aabb2<S>) -> Aabb2<S>
Create a new AABB that is the union of the two input AABBs
pub const fn min(self) -> Point2<S>
pub const fn max(self) -> Point2<S>
pub fn center(self) -> Point2<S>
pub fn dimensions(self) -> Vec2<NonNegative<S>>
pub fn extents(self) -> Vec2<NonNegative<S>>where
S: Field,
Sourcepub fn width(self) -> NonNegative<S>
pub fn width(self) -> NonNegative<S>
X dimension
Sourcepub fn height(self) -> NonNegative<S>
pub fn height(self) -> NonNegative<S>
Y dimension
pub fn area(self) -> NonNegative<S>
pub fn contains(self, point: Point2<S>) -> bool
Sourcepub fn clamp(self, point: Point2<S>) -> Point2<S>
pub fn clamp(self, point: Point2<S>) -> Point2<S>
Clamp a given point to the AABB.
let b = Aabb2::with_minmax ([-1.0, -1.0].into(), [1.0, 1.0].into()).unwrap();
assert_eq!(b.clamp ([-2.0, 0.0].into()), [-1.0, 0.0].into());
assert_eq!(b.clamp ([ 2.0, 2.0].into()), [ 1.0, 1.0].into());
assert_eq!(b.clamp ([-0.5, 0.5].into()), [-0.5, 0.5].into());Sourcepub fn rand_point<R>(self, rng: &mut R) -> Point2<S>where
S: SampleUniform,
R: RngExt,
pub fn rand_point<R>(self, rng: &mut R) -> Point2<S>where
S: SampleUniform,
R: RngExt,
Generate a random point contained in the AABB
use rand_xorshift;
use rand::SeedableRng;
// random sequence will be the same each time this is run
let mut rng = rand_xorshift::XorShiftRng::seed_from_u64 (0);
let aabb = Aabb2::<f32>::with_minmax (
[-10.0, -10.0].into(),
[ 10.0, 10.0].into()
).unwrap();
let point = aabb.rand_point (&mut rng);
assert!(aabb.contains (point));
let point = aabb.rand_point (&mut rng);
assert!(aabb.contains (point));
let point = aabb.rand_point (&mut rng);
assert!(aabb.contains (point));
let point = aabb.rand_point (&mut rng);
assert!(aabb.contains (point));
let point = aabb.rand_point (&mut rng);
assert!(aabb.contains (point));pub fn intersects(self, other: Aabb2<S>) -> bool
pub fn intersection(self, other: Aabb2<S>) -> Option<Aabb2<S>>
pub fn corner(self, quadrant: Quadrant) -> Point2<S>
pub fn edge(self, direction: SignedAxis2) -> Aabb2<S>
pub fn extrude(self, axis: SignedAxis2, amount: Positive<S>) -> Aabb2<S>
pub fn extend(&mut self, axis: SignedAxis2, amount: Positive<S>)
pub fn with_z(self, z: Interval<S>) -> Aabb3<S>
Sourcepub fn dilate(self, amount: S) -> Option<Aabb2<S>>
pub fn dilate(self, amount: S) -> Option<Aabb2<S>>
Increase or decrease each extent by the given amount.
Returns None if any extent would become negative or if all dimensions become
zero:
let x = Aabb2::with_minmax ([0.0, 0.0].into(), [1.0, 2.0].into()).unwrap();
assert!(x.dilate (-1.0).is_none());Trait Implementations
impl<S> Copy for Aabb2<S>where
S: Copy,
impl<S> Eq for Aabb2<S>where
S: Eq,
impl<S> StructuralPartialEq for Aabb2<S>