pub struct Obb3<S> {
pub center: Point3<S>,
pub extents: Vec3<Positive<S>>,
pub orientation: Angles3<S>,
}Available on crate feature
math-utils only.Expand description
3D oriented bounding box
Fields
center: Point3<S>extents: Vec3<Positive<S>>orientation: Angles3<S>Implementations
Sourceimpl<S> Obb3<S>where
S: OrderedRing,
impl<S> Obb3<S>where
S: OrderedRing,
Sourcepub const fn new(
center: Point3<S>,
extents: Vec3<Positive<S>>,
orientation: Angles3<S>,
) -> Obb3<S>
pub const fn new( center: Point3<S>, extents: Vec3<Positive<S>>, orientation: Angles3<S>, ) -> Obb3<S>
Construct a new OBB
Sourcepub fn containing_points_with_orientation(
points: &[Point3<S>],
orientation: Angles3<S>,
) -> Option<Obb3<S>>
pub fn containing_points_with_orientation( points: &[Point3<S>], orientation: Angles3<S>, ) -> Option<Obb3<S>>
Compute the OBB of a given orientation.
Returns None if the points span an empty set.
Sourcepub fn containing_points_approx(points: &[Point3<S>]) -> Option<Obb3<S>>
pub fn containing_points_approx(points: &[Point3<S>]) -> Option<Obb3<S>>
Construct an approximate minimum OBB containing the convex hull of a given set of points.
Returns None if fewer than 4 points are given or if points span an empty set:
assert!(Obb3::containing_points_approx (
&[[0.0, 1.0, 0.0], [1.0, 0.0, 0.0], [0.0, 0.0, 1.0]].map (Point3::from)
).is_none());
assert!(Obb3::containing_points_approx (
&[[1.0, 0.0, 1.0], [0.0, 1.0, 0.0], [0.0, -1.0, 0.0], [-1.0, 0.0, -1.0]]
.map (Point3::from)
).is_none());Sourcepub fn containing_approx(
hull: &Hull3<S>,
mesh: &VertexEdgeTriangleMesh,
) -> Option<Obb3<S>>
pub fn containing_approx( hull: &Hull3<S>, mesh: &VertexEdgeTriangleMesh, ) -> Option<Obb3<S>>
Construct an approximate minimum OBB containing the given convex hull and corresponding mesh.
Returns None if fewer than 4 points are given or if points span an empty set:
let (hull, mesh) = Hull3::from_points_with_mesh (
&[[0.0, 1.0, 0.0], [1.0, 0.0, 0.0], [0.0, 0.0, 1.0]].map (Point3::from)
).unwrap();
assert!(Obb3::containing_approx (&hull, &mesh).is_none());
let (hull, mesh) = Hull3::from_points_with_mesh (
&[[1.0, 0.0, 1.0], [0.0, 1.0, 0.0], [0.0, -1.0, 0.0], [-1.0, 0.0, -1.0]]
.map (Point3::from)
).unwrap();
assert!(Obb3::containing_approx (&hull, &mesh).is_none());Sourcepub fn containing_approx_pca(hull: &Hull3<S>) -> Option<Obb3<S>>
pub fn containing_approx_pca(hull: &Hull3<S>) -> Option<Obb3<S>>
Construct an approximate minimum OBB containing the given convex hull of points oriented according to principal component analysis bases.
Returns None if fewer than 4 points are given or if points span an empty set:
let hull = Hull3::from_points (
&[[0.0, 1.0, 0.0], [1.0, 0.0, 0.0], [0.0, 0.0, 1.0]].map (Point3::from)
).unwrap();
assert!(Obb3::containing_approx_pca (&hull).is_none());
let hull = Hull3::from_points (
&[[1.0, 0.0, 1.0], [0.0, 1.0, 0.0], [0.0, -1.0, 0.0], [-1.0, 0.0, -1.0]]
.map (Point3::from)
).unwrap();
assert!(Obb3::containing_approx_pca (&hull).is_none());pub fn dimensions(self) -> Vec3<Positive<S>>
pub fn volume(self) -> Positive<S>
pub fn corners(self) -> [Point3<S>; 8]
pub fn aabb(self) -> Aabb3<S>