Crate nsys



Native Systems Rust namespace

Re-exports

pub use color_utils as color;
pub use curses_utils as curses;
pub use fmod_utils as fmod;
pub use gl_utils as gl;
pub use math_utils as math;
pub use signal_utils as signal;

Modules

file
File utilities
geometry
Geometry utilities
log
Logging macros
macros
Utility macros
numeric
Numeric utilities

Macros

address
Print the stringified expression followed by its pointer formatting
bits
Print the stringified expression followed by its bitstring formatting
display
Print the stringified expression followed by its display formatting
for_sequence
Expands into a series of for loops with the given block of code which should treat each type uniformly.
hex
Print the stringified expression followed by its hexadecimal formatting
pretty
Print the stringified expression followed by its pretty debug formatting
show
Print the stringified expression followed by its debug formatting