pub macro error($($args:tt)*) {
...
}Available on crate feature
rs-utils only.Expand description
Log error message that includes the enclosing function name in the target
pub macro error($($args:tt)*) {
...
}rs-utils only.Log error message that includes the enclosing function name in the target