pub macro info($($args:tt)*) {
...
}Available on crate feature
rs-utils only.Expand description
Log info message that includes the enclosing function name in the target
pub macro info($($args:tt)*) {
...
}rs-utils only.Log info message that includes the enclosing function name in the target