pub macro warn($($args:tt)*) {
...
}Available on crate feature
rs-utils only.Expand description
Log warn message that includes the enclosing function name in the target
pub macro warn($($args:tt)*) {
...
}rs-utils only.Log warn message that includes the enclosing function name in the target