pub macro address($e:expr) {
...
}Available on crate feature
rs-utils only.Expand description
Print the stringified expression followed by its pointer formatting
pub macro address($e:expr) {
...
}rs-utils only.Print the stringified expression followed by its pointer formatting