pub macro bits($e:expr) {
...
}Available on crate feature
rs-utils only.Expand description
Print the stringified expression followed by its bitstring formatting
pub macro bits($e:expr) {
...
}rs-utils only.Print the stringified expression followed by its bitstring formatting