pub macro ebits($e:expr) {
...
}Available on crate feature
rs-utils only.Expand description
Print the stringified expression to stderr followed by its bitstring formatting
pub macro ebits($e:expr) {
...
}rs-utils only.Print the stringified expression to stderr followed by its bitstring formatting