pub macro ehex($e:expr) {
...
}Available on crate feature
rs-utils only.Expand description
Print the stringified expression to stderr followed by its hexadecimal formatting
pub macro ehex($e:expr) {
...
}rs-utils only.Print the stringified expression to stderr followed by its hexadecimal formatting