pub macro hex($e:expr) {
...
}Available on crate feature
rs-utils only.Expand description
Print the stringified expression followed by its hexadecimal formatting
pub macro hex($e:expr) {
...
}rs-utils only.Print the stringified expression followed by its hexadecimal formatting