pub macro pretty($e:expr) {
...
}Available on crate feature
rs-utils only.Expand description
Print the stringified expression followed by its pretty debug formatting
pub macro pretty($e:expr) {
...
}rs-utils only.Print the stringified expression followed by its pretty debug formatting