Module macros

Module macros 

Available on crate feature rs-utils only.
Utility macros

Macros

address
Print the stringified expression followed by its pointer formatting
bits
Print the stringified expression followed by its bitstring formatting
display
Print the stringified expression followed by its display formatting
for_sequence
Expands into a series of for loops with the given block of code which should treat each type uniformly.
hex
Print the stringified expression followed by its hexadecimal formatting
pretty
Print the stringified expression followed by its pretty debug formatting
show
Print the stringified expression followed by its debug formatting