for_sequence

Macro for_sequence 

pub macro for_sequence( $pattern:pat in ($($iter:expr),+) $do:block
  ) {
    ...
}
Available on crate feature rs-utils only.
Expands into a series of for loops with the given block of code which should treat each type uniformly.

This is to avoid dynamic dispatch when chaining iterators over generic collections when the types are known.