max_partial

Function max_partial 

pub fn max_partial<S>(lhs: S, rhs: S) -> S
where S: Copy + PartialOrd,
Available on crate feature rs-utils only.
Returns the maximum of two partially ordered values, returning the rhs when they are incomparable.

This follows the convention of f32::min and f32::max, but the opposite convention is used internally by the collision crate.