Module file

Module file 

Available on crate feature rs-utils only.
File utilities

Functions

file_new_append
Opens a new file at specified path for writing in append mode, recursively creating parent directories
file_new_append_incremental
Calls file_new_append on the path returned by feeding the file path to file_path_incremental.
file_path_incremental
Returns the file path appended with suffix -N where N gives the first available non-pre-existing filename starting from 0.
file_path_incremental_with_extension
Like file path incremental but preserves the file extension if one is present.
is_file
If this returns true then std::fs::File::create will not fail with “is a directory” error.