Available on crate feature
rs-utils only.Expand description
Logging macros
Modules
- kv
- The usual key-value format for log macros is to put the keys before the message, the macros in this module reverses this order so that the log message comes before the key/value pairs.
Macros
- debug
- Log debug message that includes the enclosing function name in the target
- error
- Log error message that includes the enclosing function name in the target
- info
- Log info message that includes the enclosing function name in the target
- trace
- Log trace message that includes the enclosing function name in the target
- warn
- Log warn message that includes the enclosing function name in the target
Enums
- Level
Filter - An enum representing the available verbosity level filters of the logger.